/*
 * Copyright 2017 Groupon, Inc.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
"use strict";
/**
 * Copyright 2017 Groupon, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var child_process_1 = require("child_process");
var prompt = require("prompt");
var BaseAdapter = /** @class */ (function () {
    function BaseAdapter(config, ticket) {
        this.config = config;
        this.ticket = ticket;
    }
    BaseAdapter.prototype.start = function () {
        var _this = this;
        prompt.start();
        this.promptForTicketName().then(function () { return _this.checkoutBranch(); });
    };
    BaseAdapter.prototype.promptForTicketName = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            return _this.fetchDefaultTicketName().then(function (defaultTicketName) {
                prompt.get(_this.getTicketNameSchema(defaultTicketName), function (err, result) {
                    if (err) {
                        reject(err);
                    }
                    _this.ticketName = result.ticketName || defaultTicketName;
                    resolve();
                });
            });
        });
    };
    BaseAdapter.prototype.getTicketNameSchema = function (defaultTicketName) {
        var description = 'Brief description';
        if (defaultTicketName) {
            description += " (default: \"" + defaultTicketName + "\")";
        }
        return {
            name: 'ticketName',
            description: description,
            type: 'string',
            required: !defaultTicketName,
        };
    };
    BaseAdapter.prototype.checkoutBranch = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var branchName = _this.ticket + "--" + _this.getNormalizedBranchName();
            var cmd = "git checkout -b " + branchName;
            child_process_1.exec(cmd, function (err, stdout, stderr) {
                if (err) {
                    reject(err);
                }
                if (stderr) {
                    console.error(stderr);
                }
                console.log(stdout);
                resolve();
            });
        });
    };
    BaseAdapter.prototype.getNormalizedBranchName = function () {
        // Replace all non-word characters with hypens, and strip all non-word characters from the beginning and end.
        return this.ticketName
            .replace(/\W+/g, '-')
            .replace(/^\W+/g, '')
            .replace(/\W+$/g, '');
    };
    return BaseAdapter;
}());
exports.default = BaseAdapter;
//# sourceMappingURL=base-adapter.js.map